<!-- markdownlint-disable -->

<a href="..\..\qtstrap\extras\code_editor\code_line.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.code_editor.code_line`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\extras\code_editor\code_line.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CodeLine`




<a href="..\..\qtstrap\extras\code_editor\code_line.py#L6"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeLine.__init__`

```python
__init__(*args, **kwargs)
```








---

<a href="..\..\qtstrap\extras\code_editor\code_line.py#L13"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeLine.keyPressEvent`

```python
keyPressEvent(event: PySide6.QtGui.QKeyEvent)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
